..  Copyright (C)  Brad Miller, David Ranum, Jeffrey Elkner, Peter Wentworth, Allen B. Downey, Chris
    Meyers, and Dario Mitchell.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

.. qnum::
   :prefix: test-4-
   :start: 1

Glossary
--------

.. glossary::

    return value test
      A return value test invokes a function on a particular set of inputs and checks whether the return value is the correct one for those inputs.
    
    side effect test
      A side effect test invokes a function or method and then checks whether some object's contents were suitably transformed by the end of the execution of the function or method.  
    
    test case
        An assertion about the state of the program at particular point in its
        execution, such as the type of a variable or of a value returned by a function.
